Module: Google::Cloud::Dataplex
- Defined in:
- lib/google/cloud/dataplex.rb,
lib/google/cloud/dataplex/version.rb
Constant Summary collapse
- VERSION =
"2.4.0"
Class Method Summary collapse
-
.business_glossary_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for BusinessGlossaryService.
-
.business_glossary_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the BusinessGlossaryService service is supported by the current client.
-
.catalog_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CatalogService.
-
.catalog_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CatalogService service is supported by the current client.
-
.cmek_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CmekService.
-
.cmek_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CmekService service is supported by the current client.
-
.configure {|::Google::Cloud.configure.dataplex| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-dataplex library.
-
.content_service(version: :v1, &block) ⇒ ::Object
Create a new client object for ContentService.
-
.content_service_available?(version: :v1) ⇒ boolean
Determines whether the ContentService service is supported by the current client.
-
.data_product_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for DataProductService.
-
.data_product_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the DataProductService service is supported by the current client.
-
.data_scan_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for DataScanService.
-
.data_scan_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the DataScanService service is supported by the current client.
-
.data_taxonomy_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for DataTaxonomyService.
-
.data_taxonomy_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the DataTaxonomyService service is supported by the current client.
-
.dataplex_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for DataplexService.
-
.dataplex_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the DataplexService service is supported by the current client.
-
.metadata_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for MetadataService.
-
.metadata_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the MetadataService service is supported by the current client.
Class Method Details
.business_glossary_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for BusinessGlossaryService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::BusinessGlossaryService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the BusinessGlossaryService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the BusinessGlossaryService service. You can determine whether the method will succeed by calling business_glossary_service_available?.
About BusinessGlossaryService
BusinessGlossaryService provides APIs for managing business glossary resources for enterprise customers. The resources currently supported in Business Glossary are:
- Glossary
- GlossaryCategory
- GlossaryTerm
154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/google/cloud/dataplex.rb', line 154 def self.business_glossary_service version: :v1, transport: :grpc, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:BusinessGlossaryService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.business_glossary_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the BusinessGlossaryService service is supported by the current client. If true, you can retrieve a client object by calling business_glossary_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the BusinessGlossaryService service, or if the versioned client gem needs an update to support the BusinessGlossaryService service.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/google/cloud/dataplex.rb', line 178 def self.business_glossary_service_available? version: :v1, transport: :grpc require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :BusinessGlossaryService service_module = service_module.const_get :BusinessGlossaryService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.catalog_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CatalogService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::CatalogService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the CatalogService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CatalogService service. You can determine whether the method will succeed by calling catalog_service_available?.
About CatalogService
The primary resources offered by this service are EntryGroups, EntryTypes, AspectTypes, Entries and EntryLinks. They collectively let data administrators organize, manage, secure, and catalog data located across cloud projects in their organization in a variety of storage systems, including Cloud Storage and BigQuery.
228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/google/cloud/dataplex.rb', line 228 def self.catalog_service version: :v1, transport: :grpc, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:CatalogService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.catalog_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CatalogService service is supported by the current client. If true, you can retrieve a client object by calling catalog_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CatalogService service, or if the versioned client gem needs an update to support the CatalogService service.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/google/cloud/dataplex.rb', line 252 def self.catalog_service_available? version: :v1, transport: :grpc require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :CatalogService service_module = service_module.const_get :CatalogService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.cmek_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CmekService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::CmekService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the CmekService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CmekService service. You can determine whether the method will succeed by calling cmek_service_available?.
About CmekService
Dataplex Universal Catalog Customer Managed Encryption Keys (CMEK) Service
298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/google/cloud/dataplex.rb', line 298 def self.cmek_service version: :v1, transport: :grpc, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:CmekService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.cmek_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CmekService service is supported by the current client. If true, you can retrieve a client object by calling cmek_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CmekService service, or if the versioned client gem needs an update to support the CmekService service.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/google/cloud/dataplex.rb', line 322 def self.cmek_service_available? version: :v1, transport: :grpc require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :CmekService service_module = service_module.const_get :CmekService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.dataplex| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-dataplex library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
717 718 719 720 721 |
# File 'lib/google/cloud/dataplex.rb', line 717 def self.configure yield ::Google::Cloud.configure.dataplex if block_given? ::Google::Cloud.configure.dataplex end |
.content_service(version: :v1, &block) ⇒ ::Object
Create a new client object for ContentService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::ContentService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ContentService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
Raises an exception if the currently installed versioned client gem for the given API version does not support the ContentService service. You can determine whether the method will succeed by calling content_service_available?.
About ContentService
ContentService manages Notebook and SQL Scripts for Dataplex Universal Catalog.
366 367 368 369 370 371 372 373 374 375 |
# File 'lib/google/cloud/dataplex.rb', line 366 def self.content_service version: :v1, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:ContentService) service_module.const_get(:Client).new(&block) end |
.content_service_available?(version: :v1) ⇒ boolean
Determines whether the ContentService service is supported by the current client. If true, you can retrieve a client object by calling content_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ContentService service, or if the versioned client gem needs an update to support the ContentService service.
388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/google/cloud/dataplex.rb', line 388 def self.content_service_available? version: :v1 require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :ContentService service_module = service_module.const_get :ContentService service_module.const_defined? :Client rescue ::LoadError false end |
.data_product_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for DataProductService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::DataProductService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the DataProductService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataProductService service. You can determine whether the method will succeed by calling data_product_service_available?.
About DataProductService
DataProductService provides APIs for managing data products and
the underlying data assets.
431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/google/cloud/dataplex.rb', line 431 def self.data_product_service version: :v1, transport: :grpc, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:DataProductService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.data_product_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the DataProductService service is supported by the current client. If true, you can retrieve a client object by calling data_product_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataProductService service, or if the versioned client gem needs an update to support the DataProductService service.
455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/google/cloud/dataplex.rb', line 455 def self.data_product_service_available? version: :v1, transport: :grpc require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :DataProductService service_module = service_module.const_get :DataProductService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.data_scan_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for DataScanService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::DataScanService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the DataScanService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataScanService service. You can determine whether the method will succeed by calling data_scan_service_available?.
About DataScanService
DataScanService manages DataScan resources which can be configured to run various types of data scanning workload and generate enriched metadata (e.g. Data Profile, Data Quality) for the data source.
574 575 576 577 578 579 580 581 582 583 584 |
# File 'lib/google/cloud/dataplex.rb', line 574 def self.data_scan_service version: :v1, transport: :grpc, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:DataScanService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.data_scan_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the DataScanService service is supported by the current client. If true, you can retrieve a client object by calling data_scan_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataScanService service, or if the versioned client gem needs an update to support the DataScanService service.
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/google/cloud/dataplex.rb', line 598 def self.data_scan_service_available? version: :v1, transport: :grpc require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :DataScanService service_module = service_module.const_get :DataScanService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.data_taxonomy_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for DataTaxonomyService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::DataTaxonomyService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the DataTaxonomyService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataTaxonomyService service. You can determine whether the method will succeed by calling data_taxonomy_service_available?.
About DataTaxonomyService
DataTaxonomyService enables attribute-based governance. The resources currently offered include DataTaxonomy and DataAttribute.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/google/cloud/dataplex.rb', line 502 def self.data_taxonomy_service version: :v1, transport: :grpc, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:DataTaxonomyService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.data_taxonomy_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the DataTaxonomyService service is supported by the current client. If true, you can retrieve a client object by calling data_taxonomy_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataTaxonomyService service, or if the versioned client gem needs an update to support the DataTaxonomyService service.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/google/cloud/dataplex.rb', line 526 def self.data_taxonomy_service_available? version: :v1, transport: :grpc require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :DataTaxonomyService service_module = service_module.const_get :DataTaxonomyService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.dataplex_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for DataplexService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::DataplexService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the DataplexService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataplexService service. You can determine whether the method will succeed by calling dataplex_service_available?.
About DataplexService
Dataplex service provides data lakes as a service. The primary resources offered by this service are Lakes, Zones and Assets which collectively allow a data administrator to organize, manage, secure and catalog data across their organization located across cloud projects in a variety of storage systems including Cloud Storage and BigQuery.
79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/google/cloud/dataplex.rb', line 79 def self.dataplex_service version: :v1, transport: :grpc, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:DataplexService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.dataplex_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the DataplexService service is supported by the current client. If true, you can retrieve a client object by calling dataplex_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataplexService service, or if the versioned client gem needs an update to support the DataplexService service.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/google/cloud/dataplex.rb', line 103 def self.dataplex_service_available? version: :v1, transport: :grpc require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :DataplexService service_module = service_module.const_get :DataplexService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.metadata_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for MetadataService.
By default, this returns an instance of
Google::Cloud::Dataplex::V1::MetadataService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the MetadataService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the MetadataService service. You can determine whether the method will succeed by calling metadata_service_available?.
About MetadataService
Metadata service manages metadata resources such as tables, filesets and partitions.
645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/google/cloud/dataplex.rb', line 645 def self. version: :v1, transport: :grpc, &block require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:MetadataService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.metadata_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the MetadataService service is supported by the current client. If true, you can retrieve a client object by calling metadata_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the MetadataService service, or if the versioned client gem needs an update to support the MetadataService service.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/google/cloud/dataplex.rb', line 669 def self. version: :v1, transport: :grpc require "google/cloud/dataplex/#{version.to_s.downcase}" package_name = Google::Cloud::Dataplex .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Dataplex.const_get package_name return false unless service_module.const_defined? :MetadataService service_module = service_module.const_get :MetadataService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |