Module: Google::Cloud::Dataplex

Defined in:
lib/google/cloud/dataplex.rb,
lib/google/cloud/dataplex/version.rb

Constant Summary collapse

VERSION =
"2.1.0"

Class Method Summary collapse

Class Method Details

.catalog_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for CatalogService.

By default, this returns an instance of Google::Cloud::Dataplex::V1::CatalogService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the CatalogService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CatalogService service. You can determine whether the method will succeed by calling catalog_service_available?.

About CatalogService

The primary resources offered by this service are EntryGroups, EntryTypes, AspectTypes, and Entries. They collectively let data administrators organize, manage, secure, and catalog data located across cloud projects in their organization in a variety of storage systems, including Cloud Storage and BigQuery.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



153
154
155
156
157
158
159
160
161
162
163
# File 'lib/google/cloud/dataplex.rb', line 153

def self.catalog_service version: :v1, transport: :grpc, &block
  require "google/cloud/dataplex/#{version.to_s.downcase}"

  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:CatalogService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.catalog_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the CatalogService service is supported by the current client. If true, you can retrieve a client object by calling catalog_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CatalogService service, or if the versioned client gem needs an update to support the CatalogService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/google/cloud/dataplex.rb', line 177

def self.catalog_service_available? version: :v1, transport: :grpc
  require "google/cloud/dataplex/#{version.to_s.downcase}"
  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Dataplex.const_get package_name
  return false unless service_module.const_defined? :CatalogService
  service_module = service_module.const_get :CatalogService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.cmek_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for CmekService.

By default, this returns an instance of Google::Cloud::Dataplex::V1::CmekService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the CmekService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CmekService service. You can determine whether the method will succeed by calling cmek_service_available?.

About CmekService

Dataplex Cmek Service

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



223
224
225
226
227
228
229
230
231
232
233
# File 'lib/google/cloud/dataplex.rb', line 223

def self.cmek_service version: :v1, transport: :grpc, &block
  require "google/cloud/dataplex/#{version.to_s.downcase}"

  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:CmekService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.cmek_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the CmekService service is supported by the current client. If true, you can retrieve a client object by calling cmek_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CmekService service, or if the versioned client gem needs an update to support the CmekService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/google/cloud/dataplex.rb', line 247

def self.cmek_service_available? version: :v1, transport: :grpc
  require "google/cloud/dataplex/#{version.to_s.downcase}"
  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Dataplex.const_get package_name
  return false unless service_module.const_defined? :CmekService
  service_module = service_module.const_get :CmekService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.configure {|::Google::Cloud.configure.dataplex| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-dataplex library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



578
579
580
581
582
# File 'lib/google/cloud/dataplex.rb', line 578

def self.configure
  yield ::Google::Cloud.configure.dataplex if block_given?

  ::Google::Cloud.configure.dataplex
end

.content_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for ContentService.

By default, this returns an instance of Google::Cloud::Dataplex::V1::ContentService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ContentService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ContentService service. You can determine whether the method will succeed by calling content_service_available?.

About ContentService

ContentService manages Notebook and SQL Scripts for Dataplex.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



293
294
295
296
297
298
299
300
301
302
303
# File 'lib/google/cloud/dataplex.rb', line 293

def self.content_service version: :v1, transport: :grpc, &block
  require "google/cloud/dataplex/#{version.to_s.downcase}"

  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:ContentService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.content_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the ContentService service is supported by the current client. If true, you can retrieve a client object by calling content_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ContentService service, or if the versioned client gem needs an update to support the ContentService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/google/cloud/dataplex.rb', line 317

def self.content_service_available? version: :v1, transport: :grpc
  require "google/cloud/dataplex/#{version.to_s.downcase}"
  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Dataplex.const_get package_name
  return false unless service_module.const_defined? :ContentService
  service_module = service_module.const_get :ContentService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.data_scan_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for DataScanService.

By default, this returns an instance of Google::Cloud::Dataplex::V1::DataScanService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DataScanService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataScanService service. You can determine whether the method will succeed by calling data_scan_service_available?.

About DataScanService

DataScanService manages DataScan resources which can be configured to run various types of data scanning workload and generate enriched metadata (e.g. Data Profile, Data Quality) for the data source.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



436
437
438
439
440
441
442
443
444
445
446
# File 'lib/google/cloud/dataplex.rb', line 436

def self.data_scan_service version: :v1, transport: :grpc, &block
  require "google/cloud/dataplex/#{version.to_s.downcase}"

  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:DataScanService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.data_scan_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the DataScanService service is supported by the current client. If true, you can retrieve a client object by calling data_scan_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataScanService service, or if the versioned client gem needs an update to support the DataScanService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/google/cloud/dataplex.rb', line 460

def self.data_scan_service_available? version: :v1, transport: :grpc
  require "google/cloud/dataplex/#{version.to_s.downcase}"
  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Dataplex.const_get package_name
  return false unless service_module.const_defined? :DataScanService
  service_module = service_module.const_get :DataScanService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.data_taxonomy_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for DataTaxonomyService.

By default, this returns an instance of Google::Cloud::Dataplex::V1::DataTaxonomyService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DataTaxonomyService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataTaxonomyService service. You can determine whether the method will succeed by calling data_taxonomy_service_available?.

About DataTaxonomyService

DataTaxonomyService enables attribute-based governance. The resources currently offered include DataTaxonomy and DataAttribute.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



364
365
366
367
368
369
370
371
372
373
374
# File 'lib/google/cloud/dataplex.rb', line 364

def self.data_taxonomy_service version: :v1, transport: :grpc, &block
  require "google/cloud/dataplex/#{version.to_s.downcase}"

  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:DataTaxonomyService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.data_taxonomy_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the DataTaxonomyService service is supported by the current client. If true, you can retrieve a client object by calling data_taxonomy_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataTaxonomyService service, or if the versioned client gem needs an update to support the DataTaxonomyService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/google/cloud/dataplex.rb', line 388

def self.data_taxonomy_service_available? version: :v1, transport: :grpc
  require "google/cloud/dataplex/#{version.to_s.downcase}"
  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Dataplex.const_get package_name
  return false unless service_module.const_defined? :DataTaxonomyService
  service_module = service_module.const_get :DataTaxonomyService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.dataplex_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for DataplexService.

By default, this returns an instance of Google::Cloud::Dataplex::V1::DataplexService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DataplexService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataplexService service. You can determine whether the method will succeed by calling dataplex_service_available?.

About DataplexService

Dataplex service provides data lakes as a service. The primary resources offered by this service are Lakes, Zones and Assets which collectively allow a data administrator to organize, manage, secure and catalog data across their organization located across cloud projects in a variety of storage systems including Cloud Storage and BigQuery.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



79
80
81
82
83
84
85
86
87
88
89
# File 'lib/google/cloud/dataplex.rb', line 79

def self.dataplex_service version: :v1, transport: :grpc, &block
  require "google/cloud/dataplex/#{version.to_s.downcase}"

  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:DataplexService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.dataplex_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the DataplexService service is supported by the current client. If true, you can retrieve a client object by calling dataplex_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataplexService service, or if the versioned client gem needs an update to support the DataplexService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/google/cloud/dataplex.rb', line 103

def self.dataplex_service_available? version: :v1, transport: :grpc
  require "google/cloud/dataplex/#{version.to_s.downcase}"
  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Dataplex.const_get package_name
  return false unless service_module.const_defined? :DataplexService
  service_module = service_module.const_get :DataplexService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.metadata_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for MetadataService.

By default, this returns an instance of Google::Cloud::Dataplex::V1::MetadataService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the MetadataService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the MetadataService service. You can determine whether the method will succeed by calling metadata_service_available?.

About MetadataService

Metadata service manages metadata resources such as tables, filesets and partitions.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



507
508
509
510
511
512
513
514
515
516
517
# File 'lib/google/cloud/dataplex.rb', line 507

def self. version: :v1, transport: :grpc, &block
  require "google/cloud/dataplex/#{version.to_s.downcase}"

  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Dataplex.const_get(package_name).const_get(:MetadataService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.metadata_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the MetadataService service is supported by the current client. If true, you can retrieve a client object by calling metadata_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the MetadataService service, or if the versioned client gem needs an update to support the MetadataService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/google/cloud/dataplex.rb', line 531

def self. version: :v1, transport: :grpc
  require "google/cloud/dataplex/#{version.to_s.downcase}"
  package_name = Google::Cloud::Dataplex
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Dataplex.const_get package_name
  return false unless service_module.const_defined? :MetadataService
  service_module = service_module.const_get :MetadataService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end